{# Display Success #} {% if job_data['statistics']['task_success'] %} {% set portlet_colour = 'green-soft' %} {% else %} {% set portlet_colour = 'red-sunglo' %} {% end %} {# Conversion Process #} {% if 'start_time' in job_data['statistics'] %} {% set start_time = job_data['statistics']['start_time'] %} {% else %} {% set start_time = False %} {% end %} {% if 'finish_time' in job_data['statistics'] %} {% set finish_time = job_data['statistics']['finish_time'] %} {% else %} {% set finish_time = False %} {% end %} {% if 'start_datetime' in job_data['statistics'] %} {% set start_datetime = job_data['statistics']['start_datetime'] %} {% else %} {% set start_datetime = False %} {% end %} {% if 'finish_datetime' in job_data['statistics'] %} {% set finish_datetime = job_data['statistics']['finish_datetime'] %} {% else %} {% set finish_datetime = False %} {% end %}
Conversion Process
{% if start_time %}
Start Time:
{{ start_datetime }}
{% end %} {% if finish_time %}
Finish Time:
{{ finish_datetime }}
{% end %} {% if 'duration' in job_data['statistics'] %}
Task Duration:
{{ job_data['statistics']['duration'] }}
{% end %}
{# TODO: Imporve on audio and video encoder information (perhaps add images?) #} {% if 'video_encoder' in job_data['statistics'] %}
Video Encoder:
{{ job_data['statistics']['video_encoder'] }}
{% end %} {% if 'audio_encoder' in job_data['statistics'] %}
Audio Encoder:
{{ job_data['statistics']['audio_encoder'] }}
{% end %}
{# File Size Comparison #} {% if job_data['statistics']['task_success'] %}
File Size Comparison
{% end %} {# FFMPEG Command Log #} {% if 'ffmpeg_log' in job_data %}
FFMPEG Command Log
{% if job_data['ffmpeg_log'] %} {% for foo in job_data.get('ffmpeg_log_lines') %} {% raw foo %}
{% end %} {% else %}

    No FFMPEG command log recorded for this task.

{% end %}
{% end %}